@@ -10,7 +10,7 @@ our @EXPORT_OK = qw(
                        declare_function_dep
                );
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 sub declare_function_dep {
     my %args    = @_;
@@ -53,11 +53,7 @@ Perinci::Sub::DepUtil - Utility routines for Perinci::Sub::Dep::* modules
 
 =head1 VERSION
 
-version 0.02
-
-=head1 RELEASE DATE
-
-2014-04-27
+This document describes version 0.03 of Perinci::Sub::DepUtil (from Perl distribution Perinci-Sub-DepUtil), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -77,7 +73,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Su
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-DepUtil>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-DepUtil>.
 
 =head1 BUGS
 
@@ -89,11 +85,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
